<?php
namespace Folha\Logic\ESocial\Eventos\Data;
use Folha\Repositories\GpeEsocialRegistro;

/**
 * Classe provedora do datasource utilizado para a geracao do evento S-1200 - Remuneração do Trabalhador.
 *
 * @package Folha\Logic\ESocial\Eventos\Data
 * @author felipesantos
 **/
class S1200
{

    /**
     * Retorna os dados que serao utilizado para a geracao do(s) arquivo(s) do evento S-1200, Remuneração do Trabalhador.
     *
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $idRetificacao           Identificador de Retificação dos arquivos ou não.
     * @param $nrRecibo                Número do Recibo do primeiro envio em caso de Retificação.
     * @param $idApuracao              Identificador da apuração Mensal ou Anual.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author felipesantos
     **/
    public static function getDataSource($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
                                         $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente, $indRetificacao, $nrRecibo, $indApuracao)
    {
        $S1200 = \Folha\Repositories\GpeEsocialRegistro::dataSetEsocial_S1200(
            $dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
            $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente, $indRetificacao, $nrRecibo, $indApuracao
        );

        $contVinculos = 0;
        foreach ($S1200 as &$row) {
            if ($versaoEsocial === \ESocial::VERSAO_2_0) {
                $itensRemun = null;
                $remunPerApur = null;
                $ideEstabLot = null;
                $recPagtos = null;

                $lotacoes = GpeEsocialRegistro::s1200_estabLotacao($fimPeriodo, $row['NRVINCULOM'], $nrorg);

                foreach ($lotacoes as $lotacao) {
                    $remuneracoes = GpeEsocialRegistro::s1200_remunPorPeriodo($inicioPeriodo, $fimPeriodo, $row['NRVINCULOM'], $nrorg);

                    foreach ($remuneracoes as $remun) {
                        $itens = GpeEsocialRegistro::s1200_ItemRemuneracao($inicioPeriodo, $fimPeriodo, $row['NRVINCULOM'], $nrorg);

                        foreach ($itens as $item) {
                            $itensRemun[] =
                                array(
                                    "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_ITENSREMUN_CODRUBR" => $item['CODRUBR'],
                                    "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_ITENSREMUN_IDETABRUBR" => $item['IDETABRUBR'],
                                    "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_ITENSREMUN_QTDRUBR" => $item['QTDRUBR'],
                                    "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_ITENSREMUN_VRUNIT" => $item['VRUNIT'],
                                    "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_ITENSREMUN_VRRUBR" => $item['VRRUBR']
                                );
                        }

                        $remunPerApur[] =
                            array(
                                "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_MATRICULA" => $remun['MATRICULA'],
                                "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_CODCATEG" => $remun['CODCATEG'],
                                "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_VLRLIQ" => $remun['VLRLIQ'],
                                "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_INDRESBR" => $remun['INDRESBR'],
                                "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_DTPAGTO" => $remun['DTPAGTO'],
                                "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_INDSIMPLES" => $remun['INDSIMPLES'],
                                "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR_ITENSREMUN" => $itensRemun
                            );
                    }

                    $ideEstabLot[] =
                        array(
                            "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_TPINSC" => $lotacao['TPINSC'],
                            "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_NRINSC" => $lotacao['NRINSC'],
                            "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_CODLOTACAO" => $lotacao['CODLOTACAO'],
                            "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT_REMUNPERAPUR" => $remunPerApur
                        );
                }

                $recPagtos[] =
                    array(
                        "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDERECPGTO" => $row['IDERECPGTO'],
                        "_EVTREMUN_INFOPERAPUR_RECPGTOS_IDEESTABLOT" => $ideEstabLot
                    );

                $row['INFOPERAPUR'] = 1;
                $row['RECPGTOS'] = $recPagtos;
            }
            else {
                $itensRemun = null;
                $remunPeriodoApuracao = null;

                $itens = GpeEsocialRegistro::s1200_itemRemuneracao($inicioPeriodo, $fimPeriodo, $row['NRVINCULOM'], $nrorg);

                $contItensRemun = 0;
                foreach ($itens as &$item) {
                    $itensRemun[$contItensRemun] =
                        array("_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_ITENSREMUN" => '1',
                            "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_ITENSREMUN_CODRUBRICA" => $item['CODRUBRICA'],
                            "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_ITENSREMUN_QTDRUBRICA" => $item['QTDRUBRICA'],
                            "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_ITENSREMUN_VLRUNITARIO" => $item['VLRUNITARIO'],
                            "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_ITENSREMUN_VLRRUBRICA" => $item['VLRRUBRICA']);
                    $contItensRemun++;
                }

                $remunPeriodoApuracao[$contVinculos] =
                    array("_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO" => '1',
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_MATRICULA" => $row['MATRICULA'],
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_CODCATEG" => $row['CODCATEG'],
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_BCCP" => $row['BCCP'],
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_BCIRRF" => $row['BCIRRF'],
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_BCFGTS" => $row['BCFGTS'],
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_DESCCP" => $row['DESCCP'],
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_VLRPROVENTOS" => $row['VLRPROVENTOS'],
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_VLRDESCONTOS" => $row['VLRDESCONTOS'],
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_VLRLIQUIDO" => $row['VLRLIQUIDO'],
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_ITENSREMUN" => $itensRemun,
                        "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO_INFOAGENTENOCIVO_GRAUEXP" => $row['GRAUEXP']);

                $row['INFOPERIODOAPURACAO'][0] =
                    array($row['IDEESTABLOTACAO'][0] =
                        array("_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO" => '1',
                            "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_TPINSCRICAO" => $row['LOTATPINSCRICAO'],
                            "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_NRINSCRICAO" => $row['LOTANRINSCRICAO'],
                            "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_CODLOTACAO" => $row['CODLOTACAO'],
                            "_EVTFPREMUNERACAO_INFOPERIODOAPURACAO_IDEESTABLOTACAO_REMUNPERIODOAPURACAO" => $remunPeriodoApuracao));

                $contVinculos++;
            }
        }

        return $S1200;
    }

}